==> VariantFiltering_1.10.1.tar.gz: VariantFiltering/man/MafDb2-class.Rd <==
\name{MafDb2-class}
\docType{class}
\alias{MafDb2-class}
\alias{MafDb2}

\alias{annotateVariants,MafDb2-method}
\alias{mafByOverlaps,MafDb2-method}
\alias{mafByOverlaps}
\alias{mafById,MafDb2-method}
\alias{mafById}
\alias{populations,MafDb2-method}
\alias{populations}
%%\alias{keytypes,MafDb2-method}
%%\alias{keytypes}
%%\alias{keys,MafDb2-method}
%%\alias{keys}
%%\alias{columns,MafDb2-method}
%%\alias{columns}
%%\alias{select,MafDb2-method}
%%\alias{select}
%%\alias{codeAF2RAW}
%%\alias{decodeRAW2AF}
\alias{organism,MafDb2-method}
\alias{provider,MafDb2-method}
\alias{providerVersion,MafDb2-method}
\alias{referenceGenome,MafDb2-method}
\alias{seqinfo,MafDb2-method}
\alias{seqlengths,MafDb2-method}
\alias{seqnames,MafDb2-method}
\alias{seqlevelsStyle,MafDb2-method}
\alias{show,MafDb2-method}
\alias{$,MafDb2-method}

%%\S4method{keytypes}{MafDb2}(x)
%%\S4method{keys}{MafDb2}(x, keytype)
%%\S4method{columns}{MafDb2}(x)
%%\S4method{select}{MafDb2}(x, keys, columns, keytype)
%%\S4method{annotateVariants}{MafDb2}(annObj, variantsVR, param, BPPARAM=bpparam("SerialParam"))

\title{MafDb2 class}

\description{
Class for annotation packages storing minor allele frequency data.
}
\usage{
\S4method{mafByOverlaps}{MafDb2}(x, ranges, pop, caching)
\S4method{mafById}{MafDb2}(x, ids, pop, caching)
\S4method{populations}{MafDb2}(x)
}
\arguments{
  \item{x}{A \code{MafDb2} object.}
  \item{ranges}{Either a \code{GRanges} object, a \code{GPos} object or a character string vector with the format \code{"CHR:START[-END]"}.}
  \item{ids}{A character string vector with variant identifiers annotated by the MAF data source, typically dbSNP 'rs' identifiers. Note that the mapping of these identifiers to genomic positions and MAF values might be a subset of the most up to date dbSNP 'rs' identifier assignment to variants. To access the latter, please use the \code{snpsById()} method from the \code{BSgenome} package with the desired \code{SNPlocs.*} package.}
  \item{pop}{A character string vector with the populations for which we want to retrieve MAF values.}
  \item{caching}{logical; TRUE (default) indicates that the function stores into main memeory the MAF data as it gets loaded from disk, improving performance; FALSE forces this function to load MAF data from disk each time, decreasing performance and memory requirements.}
%%  \item{varID}{A variant identifier, typically a \code{rsxxxx} dbSNP identifier.}
%%  \item{keytype}{the keytype that matches the keys used. For \code{MafDb2} objects
%%    there is at the moment only one type of key which is the variant identifier
%%    provided by the original data manufacturer.}
%%  \item{keys}{the keys to select records from the database. All possible keys
%%    are turned by using the \code{keys} method.}
%%  \item{columns}{the columns or kinds of things that can be retrieved from the
%%    database. As with \code{keys}, all possible columns are returned by using the
%%    \code{columns} method.}
%%  \item{annObj}{A \code{MafDb2} object.}
%%  \item{variantsVR}{A \code{VRanges} object with the variants to annotate.}
%%  \item{param}{A \code{\link{VariantFilteringParam-class}} object.}
%%  \item{BPPARAM}{An object of class \code{BiocParallelParam} specifying parameters related to
%%    the parallel execution of this function. See function \code{\link[BiocParallel]{bpparam}()}
%%    from the \code{BiocParallel} package.}
}
\details{
The \code{MafDb2} class and associated methods serve the purpose of creating
annotation packages that store minor allele frequency data that can be queried by genomic position. Two such annotation packages are:

\tabular{ll}{
  \code{MafDb.ExAC.r0.3.1.snvs.hs37d5} \tab MAF values from the ExAC consortium. \cr
  \code{MafDb.ExAC.r0.3.1.nonTCGA.snvs.hs37d5} \tab MAF values from the ExAC consortium. \cr
}

This object class tries to reduce the disk space required to store allele frequencies (AFs)
for millions of SNPs by coding AF float values, which range between 0 and 1, into a single-byte
\code{raw} object type. To achieve this, the original AF values are rounded to one significant
digit for AF < 0.01 and two significant digits for AF >= 0.01.

A further compression of these data is performed in the cases of variants with mutiple
alternative alleles. In those cases, instead of storing the AF of each alternate allele only
the maximum AF value is stored.
}
\author{R. Castelo}
\examples{

  ## lookup allele frequencies for rs1129038, a SNP associated to blue and brown eye colors
  ## as reported by Eiberg et al. Blue eye color in humans may be caused by a perfectly associated
  ## founder mutation in a regulatory element located within the HERC2 gene inhibiting OCA2 expression.
  ## Human Genetics, 123(2):177-87, 2008 [http://www.ncbi.nlm.nih.gov/pubmed/18172690]

  if (require(MafDb.ExAC.r0.3.1.snvs.hs37d5)) {
    mafdb <- MafDb.ExAC.r0.3.1.snvs.hs37d5
    mafdb

    ## specialized interface
    populations(mafdb)

    rng <- GRanges("15", IRanges(28356859, 28356859))
    mafByOverlaps(mafdb, rng)
    mafByOverlaps(mafdb, "15:28356859-28356859")
    mafByOverlaps(mafdb, "15:28356859")
    mafById(mafdb, "rs1129038")
  }

}

\source{
  \url{http://exac.broadinstitute.org}
}
\keyword{datasets}

==> VariantFiltering_1.12.2.tar.gz: VariantFiltering/man/MafDb2-class.Rd <==
\name{MafDb2-class}
\docType{class}
\alias{MafDb2-class}
\alias{MafDb2}

\alias{annotateVariants,MafDb2-method}
\alias{mafByOverlaps,MafDb2-method}
%%\alias{mafByOverlaps}
\alias{mafById,MafDb2-method}
%%\alias{mafById}
\alias{populations,MafDb2-method}
%%\alias{populations}
\alias{organism,MafDb2-method}
\alias{provider,MafDb2-method}
\alias{providerVersion,MafDb2-method}
\alias{referenceGenome,MafDb2-method}
\alias{seqinfo,MafDb2-method}
\alias{seqlengths,MafDb2-method}
\alias{seqnames,MafDb2-method}
\alias{seqlevelsStyle,MafDb2-method}
\alias{show,MafDb2-method}
\alias{$,MafDb2-method}

\title{MafDb2 class}

\description{
Class for annotation packages storing minor allele frequency data.
}
\usage{
\S4method{mafByOverlaps}{MafDb2}(x, ranges, pop, caching)
\S4method{mafById}{MafDb2}(x, ids, pop, caching)
\S4method{populations}{MafDb2}(x)
}
\arguments{
  \item{x}{A \code{MafDb2} object.}
  \item{ranges}{Either a \code{GRanges} object, a \code{GPos} object or a character string vector with the format \code{"CHR:START[-END]"}.}
  \item{ids}{A character string vector with variant identifiers annotated by the MAF data source, typically dbSNP 'rs' identifiers. Note that the mapping of these identifiers to genomic positions and MAF values might be a subset of the most up to date dbSNP 'rs' identifier assignment to variants. To access the latter, please use the \code{snpsById()} method from the \code{BSgenome} package with the desired \code{SNPlocs.*} package.}
  \item{pop}{A character string vector with the populations for which we want to retrieve MAF values.}
  \item{caching}{logical; TRUE (default) indicates that the function stores into main memeory the MAF data as it gets loaded from disk, improving performance; FALSE forces this function to load MAF data from disk each time, decreasing performance and memory requirements.}
}
\details{
The \code{MafDb2} class and associated methods serve the purpose of creating
annotation packages that store minor allele frequency data that can be queried by genomic position. Two such annotation packages are:

\tabular{ll}{
  \code{MafDb.1Kgenomes.phase1.hs37d5} \tab MAF values from the 1000 Genomes Project Phase 1. \cr
  \code{MafDb.1Kgenomes.phase3.hs37d5} \tab MAF values from the 1000 Genomes Project Phase 3. \cr
}

This object class tries to reduce the disk space required to store allele frequencies (AFs)
for millions of SNPs by coding AF float values, which range between 0 and 1, into a single-byte
\code{raw} object type. To achieve this, the original AF values are rounded to one significant
digit for AF < 0.01 and two significant digits for AF >= 0.01. When a variant has multiple
alternate alleles, only the larger MAF value is stored.
}
\author{R. Castelo}
\examples{

  ## lookup allele frequencies for rs1129038, a SNP associated to blue and brown eye colors
  ## as reported by Eiberg et al. Blue eye color in humans may be caused by a perfectly associated
  ## founder mutation in a regulatory element located within the HERC2 gene inhibiting OCA2 expression.
  ## Human Genetics, 123(2):177-87, 2008 [http://www.ncbi.nlm.nih.gov/pubmed/18172690]

  if (require(MafDb.1Kgenomes.phase1.hs37d5)) {
    mafdb <- MafDb.1Kgenomes.phase1.hs37d5
    mafdb

    ## specialized interface
    populations(mafdb)

    rng <- GRanges("15", IRanges(28356859, 28356859))
    mafByOverlaps(mafdb, rng)
    mafByOverlaps(mafdb, "15:28356859-28356859")
    mafByOverlaps(mafdb, "15:28356859")
    mafById(mafdb, "rs1129038")
  }

}
\keyword{datasets}
